==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Notifier/Bridge/OneSignal/Tests/OneSignalTransportFactoryTest.php <==
<?php

/*
 * This file is part of the Symfony package.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Symfony\Component\Notifier\Bridge\OneSignal\Tests;

use Symfony\Component\Notifier\Bridge\OneSignal\OneSignalTransportFactory;
use Symfony\Component\Notifier\Test\TransportFactoryTestCase;
use Symfony\Component\Notifier\Transport\TransportFactoryInterface;

/**
 * @author Tomas Norkūnas <norkunas.tom@gmail.com>
 */
final class OneSignalTransportFactoryTest extends TransportFactoryTestCase
{
    /**
     * @return OneSignalTransportFactory
     */
    public function createFactory(): TransportFactoryInterface
    {
        return new OneSignalTransportFactory();
    }

    public static function createProvider(): iterable
    {
        yield [
            'onesignal://app_id@host.test',
            'onesignal://app_id:api_key@host.test',
        ];
    }

    public static function supportsProvider(): iterable
    {
        yield [true, 'onesignal://token@host'];
        yield [false, 'somethingElse://token@host'];
    }

    public static function incompleteDsnProvider(): iterable
    {
        yield 'missing app_id' => ['onesignal://:api_key@host.test'];
        yield 'missing api_key' => ['onesignal://app_id:@host.test'];
    }

    public static function unsupportedSchemeProvider(): iterable
    {
        yield ['somethingElse://token@host'];
    }
}

==> symfony_8.0.0~rc1+dfsg.orig.tar.xz: symfony-8.0.0~rc1/src/Symfony/Component/Notifier/Bridge/OneSignal/Tests/OneSignalTransportFactoryTest.php <==
<?php

/*
 * This file is part of the Symfony package.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Symfony\Component\Notifier\Bridge\OneSignal\Tests;

use Symfony\Component\Notifier\Bridge\OneSignal\OneSignalTransportFactory;
use Symfony\Component\Notifier\Test\AbstractTransportFactoryTestCase;
use Symfony\Component\Notifier\Test\IncompleteDsnTestTrait;

/**
 * @author Tomas Norkūnas <norkunas.tom@gmail.com>
 */
final class OneSignalTransportFactoryTest extends AbstractTransportFactoryTestCase
{
    use IncompleteDsnTestTrait;

    public function createFactory(): OneSignalTransportFactory
    {
        return new OneSignalTransportFactory();
    }

    public static function createProvider(): iterable
    {
        yield [
            'onesignal://app_id@host.test',
            'onesignal://app_id:api_key@host.test',
        ];
    }

    public static function supportsProvider(): iterable
    {
        yield [true, 'onesignal://token@host'];
        yield [false, 'somethingElse://token@host'];
    }

    public static function incompleteDsnProvider(): iterable
    {
        yield 'missing app_id' => ['onesignal://:api_key@host.test'];
        yield 'missing api_key' => ['onesignal://app_id:@host.test'];
    }

    public static function unsupportedSchemeProvider(): iterable
    {
        yield ['somethingElse://token@host'];
    }
}
